package widebase.server

import java.io. { File, FileInputStream }
import java.util.Properties

import msgpack.rpcx.auth.AuthMap

import net.liftweb.common. { Loggable, Logger }

class Main extends xsbti.AppMain with Logger with Loggable {

	protected class Exit(val code: Int) extends xsbti.Exit

	def run(configuration: xsbti.AppConfiguration) = {

    Main.main(configuration.arguments)

    new Exit(0)

	}
}

/* Standalone Server.
 *
 * @author myst3r10n
 */
object Main extends Logger with Loggable {

  import scala.collection.JavaConversions._

  import widebase.db
  import widebase.rpc

  protected var auths: AuthMap = _
  protected var filter: String = _
  protected var jaas: String = _
  protected var port: Int = _
  protected var expire: Int = _
  protected var path: String = _

  def main(args: Array[String]) {

    auths = new AuthMap
    filter = ""
    jaas = "widebase-server"
    port = 64208
    expire = 300
    path = "."

    var i = 0

    while(i < args.size) {

      args(i) match {

        case "-a" =>
          i += 1
          val props = new Properties
          props.load(new FileInputStream(args(i)))
          enumerationAsScalaIterator(props.propertyNames).foreach {

            case function: String =>
              auths += function -> props.getProperty(function).split(",")

          }

        case "-f" =>
          i += 1
          filter = args(i)

        case "-j" =>
          i += 1
          jaas = args(i)

        case "-p" =>
          i += 1
          port = args(i).toInt

        case "-x" =>
          i += 1
          expire = args(i).toInt

        case path: String =>
          Main.this.path = path

        case _ =>
          error("Unfamiliar with argument: " + args(i))
          sys.exit(1)

      }

      i += 1

    }

    // Init DB
    val dbi = db.instance(path)

    // Init Server
    val server = rpc.server(dbi, jaas, auths, filter)

    server.listen(port, expire)

    info("Listen on " + port)

    server.await

    info("Shutdown by remotely call done")

  }
}

